@@ -27,13 +27,13 @@ class RedisInstance(BaseInstance):
 
 
 class ElasticSearchInstance(BaseInstance):
-    username: str
-    password: str
+    username: str = None
+    password: str = None
 
     @validator('host')
     def validate_host(cls, v):
         if not v.startswith('http'):
-            v = 'https://{}'.format(v)
+            v = 'http://{}'.format(v)
         return v
 
 
